# PSQF 6243 Example 1 using R

# Set width of output and number of digits to be printed
options("width"=70, "digits"=8)

# Lines that start with # are COMMENTS (notes to yourself)
# Each R command is contained in parentheses
# Data transformations (e.g., making new variables) must refer to a dataset 
# USE COLORS TO HELP YOU! Comments are GREEN, some system commands are BLUE,
#   Variables and file names are BLACK, labels and titles are also green
# All x= arguments below refer to the name of the dataset or variable to be used

# To execute select code, highlight it -- then click the run icon above,
#   or use keyboard short-cut control+enter in Windows

#####  Check to see if packages are downloaded, install if not, then load  #####

if (!require("readxl")) install.packages("readxl")
library(readxl) # To import excel XLSX data with labels as table

if (!require("psych")) install.packages("psych")
library(psych) # To add summary functions


################################################################################
#####            EXAMPLE 1 DATA IMPORT AND MANIPULATION                    #####
################################################################################

# Set working directory (to import and export files to)
# Paste in the folder address where "GSS_Example.xlsx" is saved in quotes
setwd("C:/Dropbox/22SP_PSQF6243/PSQF6243_Example1/")

# Import GSS_Example.xlsx data from working directory -- path = file name
Example1 = read_excel(path="GSS_Example.xlsx", sheet="GSS_Example") 
# Convert to data frame to use for analysis
Example1 = as.data.frame(Example1)

# Label variables used below (add descriptive titles) using comments instead
#   because variable labels are not allowed in many analysis packages
# Format: name = Descriptive Variable Label
# marital = 5-Category Marital Status
# happy   = 5-Category Happy Rating
# income  = Annual Income in 1000s

# Work-around to add value labels for categorical variables marital and happy
# Make a concatenated list of labels in order of values to be labeled
maritalLabels = c("1.Married", "2.Widowed", "3.Divorced", 
                  "4.Separated", "5.Never")
happyLabels   = c("1.Unhappy", "2.Neither", "3.Fairly", 
                  "4.Very", "5.Completely")
# Make new text-format string variables with the labels instead of values
Example1$maritalLabeled = maritalLabels[Example1$marital]
Example1$happyLabeled   = happyLabels[Example1$happy]


################################################################################
#####            BEGIN EXAMPLE 1 UNIVARIATE STATISTICS                     #####
################################################################################

# table prints frequency-only tables for categorical variables 
# useNA="ifany" includes missing values too  
print("R Frequency Table for Categorical Variable maritalLabeled")
table(x=Example1$maritalLabeled,useNA="ifany")

# prop.table converts frequencies into proportions
print("R Proportion Table for Categorical Variable maritalLabeled") 
prop.table(table(x=Example1$maritalLabeled,useNA="ifany"))

# barplot can generate frequency plots for numeric variables
# here is a work-around to make it use our string maritalLabeled variable
barplot(height=table(x=Example1$maritalLabeled,useNA="ifany"),
        ylab="Frequency",xlab="Marital Status") # axis labels

# here is how to trick barplot into plotting percentages instead
barplot(height=prop.table(table(x=Example1$maritalLabeled,useNA="ifany"))*100,
        ylab="Percentage",xlab="Marital Status") # axis labels

# to save a plot: open a file, create the plot, then close the file
png(file = "R Marital Percentage Plot.png")  # open file
barplot(height=prop.table(table(x=Example1$maritalLabeled,useNA="ifany"))*100,
        ylab="Percentage",xlab="Marital Status") # axis labels
dev.off()  # close file

# describe prints sample descriptive statistics for quantitative variables
# embedding describe in print allows control of number of digits printed
# quant= requests list of quantiles, IQR requests inter-quartile range
print("R Descriptive Statistics for Quantitative Variable income")
print(describe(x=Example1$income,quant=c(.25,.50,.75),IQR=TRUE),digits=4)

# describe does not include variance, so here is a command to do so
var(x=Example1$income)
# likewise, here are commands to get the mean and SD with more precision
# can have more than one command on a line if separated by semi-colon
mean(x=Example1$income); sd(x=Example1$income) 

# histogram for income in percent with 15 bins
hist(x=Example1$income, freq=FALSE, breaks=15, 
     ylab="Density",xlab="Annual Income in 100s") # axis labels

# to save a plot: open a file, create the plot, then close the file
png(file = "R Income Histogram Plot.png")  # open file
hist(x=Example1$income, freq=FALSE, breaks=15, 
     ylab="Density",xlab="Annual Income in 100s") # axis labels
dev.off()  # close file

# one more example: exploring an ordinal variable
print(describe(x=Example1$happy),digits=4)
png(file = "R Happy Percentage Plot.png")  # open file
barplot(height=prop.table(table(x=Example1$happyLabeled))*100,
        ylab="Percentage",xlab="Happiness Rating") # axis labels
dev.off()  # close file


################################################################################
#####             BONUS: CODE TO SAVE OUTPUT AS NEEDED                     #####
################################################################################

if (!require("TeachingDemos")) install.packages("TeachingDemos")
library(TeachingDemos) # To create text output files using code below

# Open output text file
txtStart(file="Example1_R_Output.txt")

# Code to generate output to be saved goes here
# describe does not include variance, so here is a command to do so
var(x=Example1$income)
# likewise, here are commands to get the mean and SD with more precision
# can have more than one command on a line if separated by semi-colon
mean(x=Example1$income); sd(x=Example1$income) 


# Close output text file
txtStop()

