// Prevent "more" messages from appearing
set more off
// Control line length
set linesize 150

// Codes that start with // are COMMENTS (notes to yourself) 

/*  USE COLORS TO HELP YOU! Comments are GREEN,STATA system commands are BLUE,
    Variables and file names are BLACK, File references and Labels in RED
    are case-sensitive and space-sensitive, no color for "wrong" though

    STATA commands must be in lower-case and variables are case-sensitive
     STATA is line-sensitive, so to continue a line use ///   */
   
/*  STATA commands do not have a line terminator
    Commas are used to distinguish options
    Data transformations (e.g., making new variables) can happen in open code
      because only one dataset can be active at a time (through STATA 15) */

//  To execute select code, highlight it -- then hit the run icon above
//    or use keyboard short-cut control+D in Windows   

********************************************************************************
*******            EXAMPLE 1 DATA IMPORT AND MANIPULATION                *******
********************************************************************************

// Paste in the folder address where "GSS_Example.xlsx" is saved between " "
cd "C:\Dropbox\22SP_PSQF6243\PSQF6243_Example1"
// Using the UIowa virtual desktop instead, it would look like this
// cd "\\Client\C:\Dropbox\22SP_PSQF6243\PSQF6243_Example1"

// IMPORT GSS_Example.xlsx data using filesave reference and exact file name
// To change all variable names to lowercase, remove "case(preserve")
clear // Clear before means close any open data
import excel "GSS_Example.xlsx", case(preserve) firstrow clear 
// Clear after means re-import if it already exists (need to start over)
                              
// Create formats: set of value labels for categorical variables marital and happy                            
label define Fmarital 1 "1.Married" 2 "2.Widowed" 3 "3.Divorced" ///
                              4 "4.Separated" 5 "5.Never"
label define Fhappy   1 "1.Unhappy" 2 "2.Neither" 3 "3.Fairly" /// 
                              4 "4.Very" 5 "5.Completely"  

// Label variables used below (add descriptive titles to each variable)
// label variable name    "name: Descriptive Variable Label"   
label variable marital "marital: 5-Category Marital Status"
label variable happy   "happy: 5-Category Happy Rating"
label variable income  "income: Annual Income in 1000s"
// Apply value labels created above: name Format
label values marital Fmarital
label values happy Fhappy

// Now Example1 dataset is ready to use


********************************************************************************
*******              BEGIN EXAMPLE 1 UNIVARIATE STATISTICS               *******
********************************************************************************                       
          
// display is like TITLE in SAS: prints text in output

// tabulate prints frequency and percentage tables, mention missing values  
display "STATA Frequency Table for Categorical Variable marital"
tabulate marital, missing

// histogram makes plots for categorical or quantitative variables
// for marital: is discrete, in percent, x-axis goes 1 to 5 using value labels
histogram marital, discrete percent xla(1/5, valuelabel)
// here is how you save that histogram (replace = write over it if already there)
graph export "STATA Marital Percentage Plot.png", replace

// summarize prints descriptive statistics for quantitative variables 
// detail asks for more than just N Mean SD Min Max
display "STATA Descriptive Statistics for Quantitative Variable income"
summarize income, detail
  
// histogram for income in percent in bins of 5 starting at 0
histogram income, percent width(5) start(0) 
// save histogram to permanent file
graph export "STATA Income Histogram Plot.png", replace

// One more example: exploring an ordinal variable
summarize happy, detail
histogram happy, discrete percent xla(1/5, valuelabel)
   

********************************************************************************
*******              BONUS: CODE TO SAVE OUTPUT AS NEEDED                *******
********************************************************************************     

// Save results to separate text file (replace if exists already)
// Btw, this code may throw an error if your filesave has spaces in it,
//   in which case you can open a log OR just copy output manually
log using Example1_STATA_Output.log, replace        
  
// Code to generate output goes here  


  
// Close log
log close  




  
       
      



